% MATLAB script built by Joost de Winter, Pavlo Bazilinskyy
% p.bazilinskyy@tue.nl, j.c.f.dewinter@tudelft.nl
clear all;close all;clc; %#ok<*CLALL>
opengl hardware %#ok<OPGLO>

participant_filtering_type=1; % set to 1 for more strict filtering, 2 for more liberal filtering
read_raw = false; % if true, then read raw data and save to .mat file

%% volume data (mean in 4-8 s interval, max in 4-8 s interval, perceived loudness in 4-8 s interval)
Vol=NaN(37,6);
x=NaN(37,598658);
for i=1:37
    if i<=30
        audioPath = fullfile('sounds', ['sound_' num2str(i) '.wav']);
        [xs,fs] = audioread(audioPath);
    else
        audioPath = fullfile('sounds', ['sound_' num2str(i-30) '.wav']);
        [xs,fs] = audioread(audioPath);
    end
    x(i,1:length(xs)) = xs;
end
%%
for i=1:30
    xs=x(i,:)';
    xs(isnan(xs))=[];
    IV=fs*1+1:fs*7.2+1;
    Vol(i,1) = mean(abs(xs(IV)));
    Vol(i,2) = max(abs(xs(IV)));
    Vol(i,3) = acousticLoudness(xs(IV),fs); % ISO standard 532-1 (Zwicker)
    Vol(i,4) = mean(acousticLoudness(xs(IV),fs,'timevarying',true));
    Vol(i,5) = acousticLoudness(xs(IV),fs,'Method','ISO 532-2'); % ISO 531-2 (Moore-Glasberg)
    Vol(i,6) = integratedLoudness(xs(IV),fs);
end

%% Import mapping with information about stimuli
[~, sound_info]  = xlsread('mapping.xlsx', 'A2:C31'); %#ok<XLSRD>

%% Process appen and heroku data from experiment
% indices to traverse in appen data
appen_indices = [17,... % 1. Instructions understood
    34,... % 2. Gender
    33,... % 3. Age
    15,... % 4. Age of obtaining driver's license
    35,... % 5. Primary mode of transportation
    30,... % 6. How many times in past 12 months did you drive a vehicle
    13,... % 7. Mileage
    18,... % 8. Number of accidents
    9,...  % 9. Country
    19,... % 10. DBQ1
    20,... % 11. DBQ2
    21,... % 12. DBQ3
    22,... % 13. DBQ4
    23,... % 14. DBQ5
    24,... % 15. DBQ6
    25,... % 16. DBQ7
    4,...  % 17. Start
    2,...  % 18. End
    8,...  % 19. Worker id
    32,... % 20. worker_code
    14,... % 21. Are you using headphones
    16,... % 22. Problems with hearing
    12];   % 23. IP

% process data for crowdsourced experiment
number_stimuli = 30;  % number of stimuli shown
repetition = 2;  % number of repetitions for stimuli

if participant_filtering_type==1 % more strict filtering
    matfile_name='data_strict_filtering.mat';
    matfile_acq_name='data_acq_strict_filtering.mat';
elseif participant_filtering_type==2 % more liberal filtering
    matfile_name='data_liberal_filtering.mat';
    matfile_acq_name='data_acq_liberal_filtering.mat';
end

% process data for crowdsourcing experiment
[X, ...
    Country, ...
    RT, ...
    Sliders, ...
    SoundIDs] = process_experiment(participant_filtering_type, ... % strict (1) or liberal (2) participant filtering
    read_raw, ...             % flag for reading raw data, and saving data as mat file
    matfile_name, ...         % file with saved data
    'appen.csv', ...          % file with appen data
    appen_indices, ...        % indices in appen data
    'heroku.xlsx', ...        % files with heroku data
    number_stimuli * repetition, ...     % number of stimuli
    5);                      % number of stimuli per block

% process data for the experiment with acquaintances
[X_acq, ...
    Country_acq, ...
    RT_acq, ...
    Sliders_acq, ...
    SoundIDs_acq] = process_experiment(participant_filtering_type, ...   % strict (1) or liberal (2) participant filtering
    read_raw, ...                 % flag for reading raw data, and saving data as mat file
    matfile_acq_name, ...         % file with saved data
    'appen_acq.csv',      ...    % file with appen data
    appen_indices, ...            % indices in appen data
    'heroku_acq.xlsx', ...  % files with heroku data
    number_stimuli * repetition, ...  % number of stimuli
    5);                          % number of stimuli per block

%% ************************************************************************
%% Postprocessing of raw data
%% ************************************************************************

%% Transform key_presses to key_pressesf0, containing the key press data in 0.1-s increments
key_pressesf = NaN(size(RT, 1), number_stimuli, 200);
NumberofSoundsPlayed = NaN(size(RT, 1), number_stimuli);
for i = 1:size(RT, 1) % loop over participants
    for j = 1:size(RT, 2) % loop over stimuli
        % fix for checking video_id
        if SoundIDs(i,j)>=1
            temp = squeeze(RT(i, j, :))/(1000);
            temp(isnan(temp)) = [];
            % if there is more than 15 seconds of data, then the trial must be invalid
            if max(temp) > 15
                temp = [];
            end
            % fill data gap for first half a second (0.5 s) of holding the key
            if length(temp) >= 2
                % if 'exactly' 0.5 seconds between the first and second press
                if (temp(2) - temp(1) > 0.475 && temp(2) - temp(1) < 0.525)
                    % fill with key press data
                    temp = [temp(1); transpose(temp(1) + 0.04:0.04:temp(2)); temp(2:end)];
                    % if the first key press is 'exactly' at 0.5 seconds
                elseif temp(1) > 0.475 && temp(1) < 0.525
                    temp =[transpose(0.04:0.04:temp(1)); temp(2:end)];
                end
            end
            % indices where key is pressed (in 0.1-second increments)
            O = 10 * unique(round(temp, 1));
            if isnan(key_pressesf(i,SoundIDs(i, j), 1))
                key_pressesf(i,SoundIDs(i, j),:) = 0;
                O(O == 0) = [];
                key_pressesf(i,SoundIDs(i, j), O) = key_pressesf(i, SoundIDs(i, j), O) + 1;
                NumberofSoundsPlayed(i, SoundIDs(i, j)) = 1;
            else
                O(O==0) = [];
                key_pressesf(i,SoundIDs(i, j),O) = key_pressesf(i, SoundIDs(i, j), O) + 1;
                % cater for 2+ repetitions
                NumberofSoundsPlayed(i,SoundIDs(i, j)) = NumberofSoundsPlayed(i,SoundIDs(i, j)) + 1;
            end
        end
    end
end
% divide key presses by the number of times the video was played
for i = 1:size(RT, 1) % loop over participants
    for j = 1:number_stimuli % loop over stimuli
        key_pressesf(i, j, :)=key_pressesf(i, j, :)./NumberofSoundsPlayed(i, j);
    end
end
%% Slider question data
slider_q = NaN(size(Sliders,1), number_stimuli, size(Sliders, 3));
for question = 1:3
    questiondata = squeeze(Sliders(:, :, question));
    for i = 1:size(Sliders, 1)
        for i2 = 1:number_stimuli
            indexes = find(SoundIDs(i, :) == i2);
            slider_q(i,i2,question) = mean(questiondata(i, indexes),'omitnan');
        end
    end
end

%% Transform key_presses to key_pressesf0, containing the key press data in 0.1-s increments
key_pressesf_acq = NaN(size(RT_acq,1),number_stimuli,200);
NumberofSoundsPlayed_acq = NaN(size(RT_acq,1),number_stimuli);
for i = 1:size(RT_acq, 1) % loop over participants
    for j = 1:size(RT_acq, 2) % loop over stimuli
        % fix for checking video_id (different than older studies)
        if SoundIDs_acq(i,j)>=1
            temp = squeeze(RT_acq(i,j,:))/(1000);
            temp(isnan(temp)) = [];
            % if there is more than 15 seconds of data, then the trial must be invalid.
            if max(temp) > 15
                temp=[];
            end
            % fill data gap for first half a second (0.5 s) of holding the key
            if length(temp)>=2
                % if 'exactly' 0.5 seconds between the first and second press
                if (temp(2) - temp(1)>0.475 && temp(2) - temp(1)<0.525)
                    % fill with key press data
                    temp = [temp(1); transpose(temp(1) + 0.04:0.04:temp(2)); temp(2:end)];
                    % if the first key press is 'exactly' at 0.5 seconds
                elseif temp(1) > 0.475 && temp(1) < 0.525
                    temp = [transpose(0.04:0.04:temp(1)); temp(2:end)];
                end
            end
            % indices where key is pressed (in 0.1-second increments)
            O = 10 * unique(round(temp,1));
            if isnan(key_pressesf_acq(i,SoundIDs_acq(i,j),1))
                key_pressesf_acq(i,SoundIDs_acq(i,j),:) = 0;
                O(O==0) = [];
                key_pressesf_acq(i,SoundIDs_acq(i,j),O) = key_pressesf_acq(i,SoundIDs_acq(i,j),O) + 1;
                NumberofSoundsPlayed_acq(i,SoundIDs_acq(i,j))=1;
            else
                O(O==0) = [];
                key_pressesf_acq(i,SoundIDs_acq(i,j),O) = key_pressesf_acq(i,SoundIDs_acq(i,j),O) + 1;
                % cater for 2+ repetitions
                NumberofSoundsPlayed_acq(i,SoundIDs_acq(i,j)) = NumberofSoundsPlayed_acq(i,SoundIDs_acq(i,j)) + 1;
            end
        end
    end
end
% Divide key presses by the number of times the video was played
for i = 1:size(RT_acq, 1) % loop over participants
    for j = 1:number_stimuli % loop over stimuli
        key_pressesf_acq(i, j, :) = key_pressesf_acq(i, j, :)./NumberofSoundsPlayed_acq(i, j);
    end
end

%% Slider question data
slider_q_acq = NaN(size(Sliders_acq, 1), number_stimuli, size(Sliders_acq, 3));
for question = 1:3
    questiondata_acq=squeeze(Sliders_acq(:, :, question));
    for i=1:size(Sliders_acq, 1)
        for i2 = 1:number_stimuli
            indexes = find(SoundIDs_acq(i, :) == i2);
            slider_q_acq(i, i2, question) = mean(questiondata_acq(i, indexes), 'omitnan');
        end
    end
end

%% Combine data
key_pressesf_combined = key_pressesf;
% combine with acquaintances data
key_pressesf_combined(size(key_pressesf, 1) + 1:size(key_pressesf, 1) + size(key_pressesf_acq, 1), :, :) = key_pressesf_acq;
slider_q_combined = slider_q;
% combine with acquaintances data
slider_q_combined(size(slider_q, 1) + 1:size(slider_q, 1) + size(slider_q_acq,1), :, :) = slider_q_acq;
time = (0.05:0.1:size(key_pressesf, 3) / 10)'; % Time vector
V = 1:10:141;

X_combined=[X;X_acq];
disp(['Combined sample - Gender, male respondents = ' num2str(sum(X_combined(:,2)==2))])
disp(['Combined sample - Gender, female respondents = ' num2str(sum(X_combined(:,2)==1))])
disp(['Combined sample - Gender, I prefer not to respond = ' num2str(sum(isnan(X_combined(:,2))))])
disp(['Combined sample - Age, mean = ' num2str(mean(X_combined(:,3),'omitnan'))])
disp(['Combined sample - Age, median = ' num2str(median(X_combined(:,3),'omitnan'))])
disp(['Combined sample - Age, SD = ' num2str(std(X_combined(:,3),'omitnan'))])

%% Most common countries (after filtering)
[~, ~, ub] = unique(Country);
test2counts = histcounts(ub, 'BinMethod','integers');
[B,I] = maxk(test2counts,10);
country_unique = unique(Country);
if (size(country_unique,1) > 0)
    disp('Most common countries (after filtering) = ')
    disp(country_unique(I)')
    disp(B)
end

%% Figure 2. Sound signal as a function of the elapsed time for two example stimuli without
% background noise (upper half) and the same stimuli with background noise (bgn) (lower half).
figure;
t=tiledlayout(2,2);
% four sound stimuli to be depicted in the figure (16 = Beeps; 30 = Tone - 2000Hz;
% 1 = Beeps - background noise; 15 = Tone - 2000Hz - background noise
VS=[16 30 1 15];
for i=1:length(VS)

    filename = fullfile('sounds', ['sound_' num2str(VS(i)) '.wav']);
    % reads data from the audio file and returns sampled data, y, and a sample rate for these data, Fs.
    [s,Fs] = audioread(filename);
    nexttile
    plot((1:length(s))/Fs,s, 'color', 'k');
    hold on
    title(char(sound_info(VS(i),3)))
    set(gca, ...
        'LooseInset', [0.01 0.01 0.01 0.01], ...
        'xlim', [0 13.6], ...
        'xtick', 0:1:14, ...
        'ylim', [-1 1]);
    xlabel('Time (s)');
    ylabel('Amplitude (-1 to 1)');
end
h = findobj('FontName', 'Helvetica');
 t.TileSpacing = 'normal';
    t.Padding = 'tight';
   set(h,'FontSize', 24,'Fontname','Arial')
set(gcf,'WindowState','maximized');
%print(gcf,'Figure2.png','-dpng','-r300');
%ax = gcf;copygraphics(ax,'Resolution',600)
%% Figure 3. Spectrogram of stimuli pure continuous tone (2000 Hz) with and without background noise.
figure; t=tiledlayout(2,1);
% two sound stimuli to be depicted in the figure
% (30 = Tone - 2000Hz; 15 = Tone - 2000Hz - background noise
VS=[30 15];
for i=1:length(VS)
    filename = fullfile('sounds', ['sound_' num2str(VS(i)) '.wav']);
    % reads data from the audio file and returns sampled data, y, and a sample rate for these data, Fs.
    [s,Fs]=audioread(filename);
    nexttile
    % spectrogram using short-time Fourier transform (F: frequencies at which the spectrogram is computed,
    % T: times at which the spectrogram is computed, P: power spectral density (PSD) of segment)
    [~,F,T,P]=spectrogram(s, 1024, 3/4*1024, [], Fs,'yaxis');
    surf(T,F/1000,10*log10(abs(P)));
    title(char(sound_info(VS(i),3)))
    xlabel('Time (s)');ylabel('Frequency (kHz)')
    h = colorbar;
    ylabel(h,'Power/frequency (dB/Hz)')
    view(0,90);
    shading interp;
    colormap('gray');
    clim([min(prctile(10*log10(abs(P(30:end,:))),0)) max(prctile(10*log10(abs(P(30:end,:))),100))])
    set(gca, ...
        'xtick', 0:100, ...
        'xlim', [0 13.6], ...
        'ylim', [.0 6.1], ...
        'tickdir', 'out', ...
        'LooseInset', [0.01 0.01 0.05 0.03])
end
h = findobj('FontName','Helvetica');
set(h,'FontSize', 24, 'Fontname', 'Arial')
t.TileSpacing = 'normal';
t.Padding = 'tight';
set(gcf,'WindowState','maximized');
%print(gcf,'Figure3.png','-dpng','-r300');
set(gcf,'WindowState','maximized');
%print(gcf,'Figure2.png','-dpng','-r300');
ax = gcf;
copygraphics(ax,'Resolution',600)

%% Figures A1-A4
for with_noise = [0 1]
    if with_noise==0
        VS=16:30; % without background noise
    elseif with_noise==1
        VS=1:15; % with background noise
    end
    figure
    t=tiledlayout(3,5);
    for i=1:length(VS)
        filename = fullfile('sounds', ['sound_' num2str(VS(i)) '.wav']);
        % reads data from the audio file and returns sampled data, y, and a sample rate for these data, Fs.
        [s,Fs] = audioread(filename);
        nexttile
        plot((1:length(s))/Fs,s, 'color', 'k');
        hold on
        title(char(sound_info(VS(i),3)))
        set(gca, ...
            'LooseInset', [0.01 0.01 0.01 0.01], ...
            'xlim', [0 13.6], ...
            'xtick',0:14,...
            'ylim', [-1 1]);
        xlabel('Time (s)');
        ylabel('Amplitude (-1 to 1)');
    end
    h = findobj('FontName', 'Helvetica');
    set(h,'Fontname','Arial')
    t.TileSpacing = 'normal';
    t.Padding = 'tight';
    if with_noise==0
    set(gcf,'WindowState','maximized');
%ax = gcf;copygraphics(ax,'Resolution',600);pause

    print(gcf,'FigureA1.png','-dpng','-r200');
    else
    set(gcf,'WindowState','maximized');
%ax = gcf;copygraphics(ax,'Resolution',600);pause
    print(gcf,'FigureA3.png','-dpng','-r200');
    end
        figure
    t=tiledlayout(3,5);

    for i=1:length(VS)
        filename = ['sounds\sound_' num2str(VS(i)) '.wav'];
        % reads data from the audio file and returns sampled data, y, and a sample rate for these data, Fs.
        [x,Fs]=audioread(filename);
        y = fft(x(:,1));
        n=length(y);
        f = (0:n-1)*(fs/n);     % frequency range
        nexttile

        plot(f,abs(y),'k')
        title(sound_info{VS(i),3})

        hold on;box on
        set(gca,'xlim',[0 3500])
        xlabel('Frequency in Hz');
        ylabel('Magnitude');
    end
    h = findobj('FontName','Helvetica');
    set(h,'Fontname','Arial')
    t.TileSpacing = 'normal';
    t.Padding = 'tight';
    if with_noise==0
    set(gcf,'WindowState','maximized');
    %ax = gcf;copygraphics(ax,'Resolution',600);pause
    print(gcf,'FigureA2.png','-dpng','-r200');
    else
    set(gcf,'WindowState','maximized');
 %   ax = gcf;copygraphics(ax,'Resolution',600);pause
    print(gcf,'FigureA4.png','-dpng','-r200');
    end
end

%% Figure 5. Key press percentage as a function of elapsed time for two selected samples.
% The legend shows the crossing deterrence score.
% The grey background indicates the time interval across which the crossing deterrence score was computed.
stats_pp = NaN(number_stimuli, size(key_pressesf_combined, 1));
for i = 1:number_stimuli
    stats_pp(i,:) = 100 * mean(mean(key_pressesf_combined(:, i, 10:72), 3), 2, 'omitnan');
end
figure;
hold on;
grid on;
box on
% colour palette for output
cm=[255 110 0 %  Beeps
    160 0 0  % Combined tone - 350Hz
    255 0 0  % Combined tone - 500Hz
    250 110 110  % Combined tone - 1000Hz
    255 180 180  % Combined tone - 2000Hz
    160 160 160  % Diesel
    0 160 0  % Intermittent tone - 350 Hz
    0 255 60  % Intermittent tone - 500 Hz
    110 255 110  % Intermittent tone - 1000 Hz
    180 255 180  % Intermittent tone - 2000 Hz
    0.0 0.0 0.0  % Tires
    0  0 160  % Tone - 350 Hz
    0 0 255  % Tone - 500 Hz
    110 110 255  % Tone - 1000 Hz
    180 180 255]/255; % Tone - 2000 Hz
symbols={'d','o','o','o','o','h','v','v','v','v','p','s','s','s','s'};
VS = [16 30]; % vector of stimuli to plot
l=NaN(1,length(VS));
for i = 1:length(VS)
    if VS(i) <= number_stimuli/2
        line_type = ':';
        colour_i = VS(i);
    else
        line_type = '-';
        colour_i = VS(i) - number_stimuli/2;
    end
    V = 100 * squeeze(mean(mean(key_pressesf_combined(:, VS(i),:), 2,'omitnan'), 1,'omitnan'));
    l(i)= plot(time,V,line_type,'Linewidth', 3, 'color', cm(colour_i,:));
end
xlabel('Time (s)')
ylabel('Mean safe cross perception rate (%)')
legend_text = strings(1, length(VS));
for i=1:length(VS)
    legend_text(i) = [char(sound_info(VS(i),3)) ...
        ' (Crossing deterrence score: ' sprintf('%0.1f', 100-mean(stats_pp(VS(i),:), ...
        'omitnan')) '%)'];
end

legend(l,legend_text,'autoupdate','off');
a = fill([1; 7.2; 7.2; 1],[-100; -100; 200; 200],[250/255 250/255 250/255]);
uistack(a,'bottom');
Ax = gca;
Ax.YGrid = 'on';
Ax.Layer = 'top';
set(gca, ...
    'LooseInset', [0.01 0.01 0.01 0.01], ...
    'xlim', [0 13.4], ...
    'xtick', 1:14, ...
    'ylim',[0 100])
h=findobj('FontName', 'Helvetica');
set(h,'FontSize', 30, 'Fontname', 'Arial')

%% Table 2. Means, standard deviations, and intercorrelations of the variables (n = 30)
% 1. Crossing deterrence score
% 2. The vehicle sound was easy to notice (0=not easy to notice, 10=easy to notice)
% 3. This sound gave me enough information that a vehicle was approaching (0=not enough information, 10=enough information)
% 4. This vehicle sound was annoying (0=not annoying, 10=extremely annoying)
% 5. Perceived loudness (Zwicker; ISO 531-1)
% 6. Perceived loudness (Moore-Glasberg; ISO 531-2)

StimuliScores=[100-mean(stats_pp,2,'omitnan') squeeze(mean(slider_q_combined,'omitnan')) Vol(1:30,3:6)];
disp('Table 2. Mean and SD')
disp([mean(StimuliScores)' std(StimuliScores)'])
disp('Table 2. Correlation coefficients of the variables for the auditory stimuli (n = 30).')
disp(round(corr(StimuliScores),2))
disp(round(corr(StimuliScores([1 2:5 7:10 12:15 17:20 22:25 27:30],:)),2))

%% Figure 6. Scatter plot of the crossing deterrence score (based on keypress inputs) and the computed loudness score of the 30 stimuli. Filled markers pertain to sounds with added background noise; open markers, that is, with a white interior, relate to sounds without any added background noise.
figure
for i = 1:30
    if i <= 15 % background noise
        scatter1 = scatter(StimuliScores(i, 7), StimuliScores(i, 1), 300, symbols{i},...
            'markerfacecolor', cm(i, :), ...
            'markeredgecolor', cm(i, :), ...
            'linewidth',3);

        hold on;
        grid on;
    else
        scatter1 = scatter(StimuliScores(i, 7), StimuliScores(i, 1), 300, symbols{i-15},...
            'markerfacecolor', 'w', ...
            'markeredgecolor', cm(i - 15, :), ...
            'linewidth',3);
        hold on;
        grid on;
    end
    box on
    scatter1.MarkerFaceAlpha = 1;
end
legend(sound_info{16:30,3},'location','eastoutside')
set(gca,'fontsize', 30)
axis square
xlabel('Moore-Glasberg loudness (–)','fontsize', 30)
ylabel('Crossing deterrence score (%)','fontsize', 30)

%% Figure 7. Scatter plot of the crossing deterrence score (based on keypress inputs) and the perceived annoyance of the 30 stimuli. Filled markers pertain to sounds with added background noise; open markers, that is, with a white interior, relate to sounds without any added background noise.
figure
for i = 1:30
    if i <= 15 % background noise
        scatter1 = scatter(StimuliScores(i, 4), StimuliScores(i, 1), 300, symbols{i},...
            'markerfacecolor', cm(i, :), ...
            'markeredgecolor', cm(i, :), ...
            'linewidth',3);

        hold on;
        grid on;
    else
        scatter1 = scatter(StimuliScores(i, 4), StimuliScores(i, 1), 300, symbols{i-15},...
            'markerfacecolor', 'w', ...
            'markeredgecolor', cm(i - 15, :), ...
            'linewidth',3);
        hold on;
        grid on;
    end
    box on
    scatter1.MarkerFaceAlpha = 1;
end
legend(sound_info{16:30,3},'location','eastoutside')
set(gca,'xlim',[3 8],'xtick',0:1:10)
set(gca,'fontsize', 30)
axis square
xlabel('Annoyance (0–10)','fontsize', 30)
ylabel('Crossing deterrence score (%)','fontsize', 30)
%% Figure 8. Scatter plot of the perceived annoyance and the perceived 'easy to notice' of the 30 stimuli. Filled markers pertain to sounds with added background noise; open markers, that is, with a white interior, relate to sounds without any added background noise.
figure
for i = 1:30
    if i <= 15 % background noise
        scatter1 = scatter(StimuliScores(i, 2), StimuliScores(i, 4), 300, symbols{i},...
            'markerfacecolor', cm(i, :), ...
            'markeredgecolor', cm(i, :), ...
            'linewidth',3);

        hold on;
        grid on;
    else
        scatter1 = scatter(StimuliScores(i, 2), StimuliScores(i, 4), 300, symbols{i-15},...
            'markerfacecolor', 'w', ...
            'markeredgecolor', cm(i - 15, :), ...
            'linewidth',3);
        hold on;
        grid on;
    end
    box on
    scatter1.MarkerFaceAlpha = 1;
end
legend(sound_info{16:30,3},'location','eastoutside')
set(gca,'xlim',[3 8],'xtick',0:1:10)
set(gca,'ylim',[3 8],'ytick',0:1:10)
set(gca,'fontsize', 30)
axis square
xlabel('Easy to notice (0–10)', 'fontsize', 30)
ylabel('Annoyance (0–10)', 'fontsize', 30)

